/////////////////////////////////////////////////////////////////////
//
// DirectIO.h
//
// Direct I/O header file for OPOS Applications. The constants
// herein are currently only recognized by Ingenico 6xxx devices
// unless otherwise noted.
//
// See your OPOS documentation for further details.
//
// Modification history
// ------------------------------------------------------------------
// 05-12-30 Initial version                                       NDJ
// 06-04-04 Added 2100, 6xxx constants                            NDJ
// 07-04-22 Added text color commands                             NDJ
//
/////////////////////////////////////////////////////////////////////

#if !defined(DIRECTIO_H)
#define      DIRECTIO_H

/////////////////////////////////////////////////////////////////////
// Numbers to pass to Direct I/O's "Command" parameter.
/////////////////////////////////////////////////////////////////////

const LONG DIO_SEND_RAW_DATA				= 0 ;
const LONG DIO_CLEAR_SCREEN					= 1 ;
const LONG DIO_DELETE_ALL_FORMS				= 2 ;
const LONG DIO_RESET_TERMINAL				= 3 ;
const LONG DIO_ENABLE_KEY_BEEP				= 4 ;
const LONG DIO_DISABLE_KEY_BEEP				= 5 ;
const LONG DIO_CONFIGURE_KEY_MASK			= 6 ;
const LONG DIO_SET_FORMAT_SPECIFIER			= 7 ;
const LONG DIO_DELETE_RECEIPT_CONTENTS		= 8 ;
const LONG DIO_SET_TEXT_FOREGROUND_COLOR	= 9 ;
const LONG DIO_SET_TEXT_BACKGROUND_COLOR	=10 ;
const LONG DIO_GET_FORM_INFO				=11 ;
const LONG DIO_VALIDATE_FORM				=12 ;
const LONG DIO_FORCE_DEFRAG					=13 ;
const LONG DIO_ENABLE_CONTACTLESS			=14 ;
const LONG DIO_DISABLE_CONTACTLESS			=15 ;
const LONG DIO_SEND_KEYBOARD_CLEAR_ENTRY	=16 ;
const LONG DIO_SEND_KEYPAD_CLEAR_ENTRY		=17 ;
const LONG DIO_SET_UIA_VARIABLE				=18 ;
const LONG DIO_GET_HEALTH_STAT				=19 ;
const LONG DIO_LOOP_BITMAPS					=20 ;

/////////////////////////////////////////////////////////////////////
// More numbers for "Command" parameter: eN-Crypt 2100 only
/////////////////////////////////////////////////////////////////////

const LONG DIO_EN2100_START                  = 100 ;
const LONG DIO_ENABLE_DEFAULT_MSR_PROMPTS    = DIO_EN2100_START + 0 ;
const LONG DIO_DISABLE_DEFAULT_MSR_PROMPTS   = DIO_EN2100_START + 1 ;

/////////////////////////////////////////////////////////////////////
// Customer-specific Direct I/O requests. These commands are
// deprecated unless otherwise noted.
/////////////////////////////////////////////////////////////////////

const LONG CSDIO_START                       = 1000 ;
const LONG CSDIO_REFRESH_WINDOW              = CSDIO_START + 1 ;

/////////////////////////////////////////////////////////////////////
// Flags for specification of key mask behavior.
/////////////////////////////////////////////////////////////////////

const LONG DIO_KM_ENABLE_NONE                     = 0x0000 ;
const LONG DIO_KM_ENABLE_ENTER                    = 0x0001 ;
const LONG DIO_KM_ENABLE_CANCEL                   = 0x0002 ;
const LONG DIO_KM_ENABLE_00                       = 0x0004 ;
const LONG DIO_KM_ENABLE_CLEAR                    = 0x0008 ;
const LONG DIO_KM_ENABLE_UP                       = 0x0020 ;
const LONG DIO_KM_ENABLE_F1                       = 0x0040 ;
const LONG DIO_KM_ENABLE_F2                       = 0x0080 ;
const LONG DIO_KM_ENABLE_F3                       = 0x0100 ;
const LONG DIO_KM_ENABLE_F4                       = 0x0200 ;
const LONG DIO_KM_ENABLE_ALL                      = 0xFFFF ;

/////////////////////////////////////////////////////////////////////
// Numbers to identify the source of incoming card data.
/////////////////////////////////////////////////////////////////////

const LONG DIO_CARD_SOURCE_MSR                   = 0 ;
const LONG DIO_CARD_SOURCE_CPEM                  = 1 ;

#endif                  // !defined(DIRECTIO_H)
